==> nextcloud-app-news-16.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/ka_GE.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "მოთხოვნა არ შედგა, ქსელთან კავშირი ხელმიუწვდომელია!",
    "Request unauthorized. Are you logged in?" : "მოთხოვნა არაა ავტორიზირებული. გავლილი გაქვთ ავტორიზაცია?",
    "Request forbidden. Are you an admin?" : "მოთხოვნა აიკრძალა. ხაართ ადმინისტრატორი?",
    "Token expired or app not enabled! Reload the page!" : "ტოკენს ამოეწურა ვადა ან აპლიკაცია არაა მოქმედი! გადატვირთეთ გვერდი! ",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "შიდა სერვერის შეცდომა! დამატებიტი ინფორმაციისთვის გთხოვთ შეამოწმოთ თქვენი data/nextcloud.log ფაილი.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "მოთხოვნა არ შედგა, Nextcloud ახლა სარემონტო რეჟიმშია!",
    "Unread articles" : "წაუკითხავი არტიკლები",
    "News" : "სიახლეები",
    "Use system cron for updates" : "განახლებისთვის გამოიყენეთ სისტემური კრონი",
    "Purge interval" : "გაწმენდის ინტერვალი",
    "Maximum read count per feed" : "თითო ლენტაზე მაქისმალური კითხვის რაოდენობა",
    "Maximum redirects" : " მაქს. გადამისამართებები",
    "Feed fetcher timeout" : "ლენტის მომპოვებლის დროის ამოწურვა",
    "Explore Service URL" : "სერვის მისამართის დათვალიერება",
    "Saved" : "შენახულია",
    "Download" : "ჩამოტვირთვა",
    "Close" : "დახურვა",
    "No articles available" : "არტიკლები ხელმიუწვდომელია",
    "No unread articles available" : "წაუკითხავი არტიკლები არაა",
    "Open website" : "ვებ-საიტის გახსნა",
    "Star article" : "არტიკლის ვარსკლავით შეფასება",
    "Unstar article" : "მოხსენით არტიკლს ვარსკლავი",
    "Keep article unread" : "დატოვეთ არტიკლი წაუკითხავი",
    "Remove keep article unread" : "მოაშორეთ არტიკლს წაუკითხავად დატოვება",
    "Username" : "მომხმარებლის სახელი",
    "by" : "მიერ",
    "from" : "დან",
    "Play audio" : "აუდიოს დაკვრა",
    "Download audio" : "აუდიოს ჩამოტვირთვა",
    "Download video" : "ვიდეოს ჩამოტვირთვა",
    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
    "Description" : "გვერდის დახასიათება",
    "right" : "მარჯვნივ",
    "Jump to next article" : "შემდეგ არტიკლზე გადასვლა",
    "left" : "მარცხნივ",
    "Jump to previous article" : "წინა არტიკლზე გადასვლა",
    "Toggle star article" : "არტიკლის ვარსკლავის გადართვა",
    "Star article and jump to next one" : "მიეცით არტიკლს ვარსკლავი და გადადით შემდეგზე",
    "Toggle keep current article unread" : "გადართეთ არტიკლის წაუკთხავად დატოვება",
    "Open article in new tab" : "არტიკლის ახალ ტაბში გახნსა",
    "Toggle expand article in compact view" : "გადართეთ არტიკლის განვრცობა კომპაქტურ ხედში",
    "Refresh" : "განახლება",
    "Load next feed" : "შემდეგი ლენტის ჩატვირთვა",
    "Load previous feed" : "წინა ლენტის ჩატვირთვა",
    "Load next folder" : "შემდეგი დირექტორიის ჩატვირთვა",
    "Load previous folder" : "წინა დირექტორიის ჩატვირთვა",
    "Scroll to active navigation entry" : "ჩამოწიეთ აქტიური ნავიგაციის შენატანისკენ",
    "Focus search field" : "მოახდინეთ ფოკუსირება ძიების ველზე",
    "Mark current article's feed/folder read" : "მონიშნეთ ამ არტიკლის ლენტა/დირექტორია წაკითხულად",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "არჩეულია Ajax-ის ან webcron-ის რეჟიმი! თქვენი ლენტა არ განახლდება!",
    "How to set up the operating system cron" : "როგორ დავაყენოთ ოპერაციული სისტემის კრონი",
    "Install and set up a faster parallel updater that uses the News app's update API" : "დააყენეთ და მოაწყვეთ უფრო სწრაფი პარალელური განახლება რომელიც მოიხმარს სიახლეების აპლიკაციის განახლების პროგრამულ ინტერფეისს",
    "Subscribe" : "გამოწერა",
    "Web address" : "Web მისამართი",
    "Feed exists already!" : "ლენტა უკვე არსებობს!",
    "Folder" : "დირექტორია",
    "No folder" : "დირექტორია არაა",
    "New folder" : "ახალი დირექტორია",
    "Folder name" : "დირექტორიის სახელი",
    "Go back" : "უკან დაბრუნება",
    "Folder exists already!" : "დირექტორია უკვე არსებობს!",
    "Credentials" : "უფლებამოსილებები",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP ძირითადი აუტენტიფიკაციის მონაცემები არ უნდა იყოს დაშიფრული! სერვერთან ან მონაცემთა ბაზის წვდომის უფლებებით ყველა შეძლებს მათ ნახვას.",
    "Password" : "პაროლი",
    "New Folder" : "ახალი დირექტორია",
    "Create" : "შექმნა",
    "Explore" : "მიმოხილვა",
    "Update failed more than 50 times" : "განახლება 50-ზე მეტჯერ დასრულდა წარუმატებლად",
    "Deleted feed" : "ლენტის გაუქმება",
    "Undo delete feed" : "ლენტის გაუქმების უკუგდება",
    "Rename" : "გადარქმევა",
    "Menu" : "მენიუ",
    "Mark read" : "მონიშნეთ წაკითხულად",
    "Unpin from top" : "ზევიდან ამოღება",
    "Pin to top" : "ზევით დამატება",
    "Newest first" : "ჯერ ახლები",
    "Oldest first" : "ჯერ ძველები",
    "Default order" : "საწყისი განლაგება",
    "Enable full text" : "სრული ტექსტის ამოქმედება",
    "Disable full text" : "სრული ტექსტის გათიშვა",
    "Unread updated" : "განახლებულის წაუკითხავად მონიშვნა",
    "Ignore updated" : "განახლებულის იგნორირება",
    "Open feed URL" : "ლენტის URL-ს გახსნა",
    "Delete" : "გაუქმება",
    "Dismiss" : "დათხოვნა",
    "Collapse" : "აკეცვა",
    "Deleted folder" : "დირექტორიის გაუქმება",
    "Undo delete folder" : "დირექტორიის გაუქმების უკუგდება",
    "Starred" : "ვარსკვლავმინიჭებული",
    "All articles" : "ყველა არტიკლი",
    "Settings" : "პარამეტრები",
    "Disable mark read through scrolling" : "გადახვევით წაკითხულად ქცევის გათიშვა",
    "Compact view" : "კომპაქტური ხედი",
    "Expand articles on key navigation" : "კლავიშის ნავიგაციისას არტიკლის განვრცობა",
    "Show all articles" : "ყველა არტიკლის ჩვენება",
    "Reverse ordering (oldest on top)" : "უკუგანლაგება (ძველები ზემოთ)",
    "Subscriptions (OPML)" : "გამოწერები (OPML)",
    "Import" : "იმპორტი",
    "Export" : "ექსპორტი",
    "Error when importing: File does not contain valid OPML" : "შეცდომა იმპორტირების დროს: ფაილი არ შეიცავს მართებულ OPML-ს",
    "Error when importing: OPML is does neither contain feeds nor folders" : "შეცდომა იმპორტირების დროს: OPML არც ლენტას მოიცავს და არც დირექტორიებს",
    "Unread/Starred Articles" : "წაუკითხავი/ვარსკლავიანი არტიკლები",
    "Error when importing: file does not contain valid JSON" : "შეცდომა იმპორტირებისას: ფაილი არ შეიცავს მართებულ JSON–ს",
    "Help" : "დახმარება",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Documentation" : "დოკუმენტაცია",
    "Report a bug" : "განაცხადეთ შეცდომა"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-news-18.1.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/ka_GE.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "მოთხოვნა არ შედგა, ქსელთან კავშირი ხელმიუწვდომელია!",
    "Request unauthorized. Are you logged in?" : "მოთხოვნა არაა ავტორიზირებული. გავლილი გაქვთ ავტორიზაცია?",
    "Request forbidden. Are you an admin?" : "მოთხოვნა აიკრძალა. ხაართ ადმინისტრატორი?",
    "Token expired or app not enabled! Reload the page!" : "ტოკენს ამოეწურა ვადა ან აპლიკაცია არაა მოქმედი! გადატვირთეთ გვერდი! ",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "შიდა სერვერის შეცდომა! დამატებიტი ინფორმაციისთვის გთხოვთ შეამოწმოთ თქვენი data/nextcloud.log ფაილი.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "მოთხოვნა არ შედგა, Nextcloud ახლა სარემონტო რეჟიმშია!",
    "Unread articles" : "წაუკითხავი არტიკლები",
    "News" : "სიახლეები",
    "Shared with me" : "გაზიარებულია ჩემთან",
    "Use system cron for updates" : "განახლებისთვის გამოიყენეთ სისტემური კრონი",
    "Purge interval" : "გაწმენდის ინტერვალი",
    "Maximum read count per feed" : "თითო ლენტაზე მაქისმალური კითხვის რაოდენობა",
    "Maximum redirects" : " მაქს. გადამისამართებები",
    "Feed fetcher timeout" : "ლენტის მომპოვებლის დროის ამოწურვა",
    "Explore Service URL" : "სერვის მისამართის დათვალიერება",
    "Saved" : "შენახულია",
    "Download" : "ჩამოტვირთვა",
    "Close" : "დახურვა",
    "No articles available" : "არტიკლები ხელმიუწვდომელია",
    "No unread articles available" : "წაუკითხავი არტიკლები არაა",
    "Open website" : "ვებ-საიტის გახსნა",
    "Star article" : "არტიკლის ვარსკლავით შეფასება",
    "Unstar article" : "მოხსენით არტიკლს ვარსკლავი",
    "Keep article unread" : "დატოვეთ არტიკლი წაუკითხავი",
    "Remove keep article unread" : "მოაშორეთ არტიკლს წაუკითხავად დატოვება",
    "Share" : "გაზიარება",
    "Username" : "მომხმარებლის სახელი",
    "by" : "მიერ",
    "from" : "დან",
    "Play audio" : "აუდიოს დაკვრა",
    "Download audio" : "აუდიოს ჩამოტვირთვა",
    "Download video" : "ვიდეოს ჩამოტვირთვა",
    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
    "Description" : "გვერდის დახასიათება",
    "right" : "მარჯვნივ",
    "Jump to next article" : "შემდეგ არტიკლზე გადასვლა",
    "left" : "მარცხნივ",
    "Jump to previous article" : "წინა არტიკლზე გადასვლა",
    "Toggle star article" : "არტიკლის ვარსკლავის გადართვა",
    "Star article and jump to next one" : "მიეცით არტიკლს ვარსკლავი და გადადით შემდეგზე",
    "Toggle keep current article unread" : "გადართეთ არტიკლის წაუკთხავად დატოვება",
    "Open article in new tab" : "არტიკლის ახალ ტაბში გახნსა",
    "Toggle expand article in compact view" : "გადართეთ არტიკლის განვრცობა კომპაქტურ ხედში",
    "Refresh" : "განახლება",
    "Load next feed" : "შემდეგი ლენტის ჩატვირთვა",
    "Load previous feed" : "წინა ლენტის ჩატვირთვა",
    "Load previous folder" : "წინა დირექტორიის ჩატვირთვა",
    "Load next folder" : "შემდეგი დირექტორიის ჩატვირთვა",
    "Scroll to active navigation entry" : "ჩამოწიეთ აქტიური ნავიგაციის შენატანისკენ",
    "Mark current article's feed/folder read" : "მონიშნეთ ამ არტიკლის ლენტა/დირექტორია წაკითხულად",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "არჩეულია Ajax-ის ან webcron-ის რეჟიმი! თქვენი ლენტა არ განახლდება!",
    "How to set up the operating system cron" : "როგორ დავაყენოთ ოპერაციული სისტემის კრონი",
    "Install and set up a faster parallel updater that uses the News app's update API" : "დააყენეთ და მოაწყვეთ უფრო სწრაფი პარალელური განახლება რომელიც მოიხმარს სიახლეების აპლიკაციის განახლების პროგრამულ ინტერფეისს",
    "Subscribe" : "გამოწერა",
    "Web address" : "Web მისამართი",
    "Feed exists already!" : "ლენტა უკვე არსებობს!",
    "Folder" : "დირექტორია",
    "No folder" : "დირექტორია არაა",
    "New folder" : "ახალი დირექტორია",
    "Folder name" : "დირექტორიის სახელი",
    "Go back" : "უკან დაბრუნება",
    "Folder exists already!" : "დირექტორია უკვე არსებობს!",
    "Credentials" : "უფლებამოსილებები",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP ძირითადი აუტენტიფიკაციის მონაცემები არ უნდა იყოს დაშიფრული! სერვერთან ან მონაცემთა ბაზის წვდომის უფლებებით ყველა შეძლებს მათ ნახვას.",
    "Password" : "პაროლი",
    "New Folder" : "ახალი დირექტორია",
    "Create" : "შექმნა",
    "Explore" : "მიმოხილვა",
    "Update failed more than 50 times" : "განახლება 50-ზე მეტჯერ დასრულდა წარუმატებლად",
    "Deleted feed" : "ლენტის გაუქმება",
    "Undo delete feed" : "ლენტის გაუქმების უკუგდება",
    "Rename" : "გადარქმევა",
    "Menu" : "მენიუ",
    "Mark read" : "მონიშნეთ წაკითხულად",
    "Unpin from top" : "ზევიდან ამოღება",
    "Pin to top" : "ზევით დამატება",
    "Newest first" : "ჯერ ახლები",
    "Oldest first" : "ჯერ ძველები",
    "Default order" : "საწყისი განლაგება",
    "Enable full text" : "სრული ტექსტის ამოქმედება",
    "Disable full text" : "სრული ტექსტის გათიშვა",
    "Unread updated" : "განახლებულის წაუკითხავად მონიშვნა",
    "Ignore updated" : "განახლებულის იგნორირება",
    "Open feed URL" : "ლენტის URL-ს გახსნა",
    "Delete" : "გაუქმება",
    "Dismiss" : "დათხოვნა",
    "Collapse" : "აკეცვა",
    "Deleted folder" : "დირექტორიის გაუქმება",
    "Undo delete folder" : "დირექტორიის გაუქმების უკუგდება",
    "Starred" : "ვარსკვლავმინიჭებული",
    "All articles" : "ყველა არტიკლი",
    "Settings" : "პარამეტრები",
    "Disable mark read through scrolling" : "გადახვევით წაკითხულად ქცევის გათიშვა",
    "Compact view" : "კომპაქტური ხედი",
    "Expand articles on key navigation" : "კლავიშის ნავიგაციისას არტიკლის განვრცობა",
    "Show all articles" : "ყველა არტიკლის ჩვენება",
    "Reverse ordering (oldest on top)" : "უკუგანლაგება (ძველები ზემოთ)",
    "Subscriptions (OPML)" : "გამოწერები (OPML)",
    "Import" : "იმპორტი",
    "Export" : "ექსპორტი",
    "Error when importing: File does not contain valid OPML" : "შეცდომა იმპორტირების დროს: ფაილი არ შეიცავს მართებულ OPML-ს",
    "Error when importing: OPML is does neither contain feeds nor folders" : "შეცდომა იმპორტირების დროს: OPML არც ლენტას მოიცავს და არც დირექტორიებს",
    "Unread/Starred Articles" : "წაუკითხავი/ვარსკლავიანი არტიკლები",
    "Error when importing: file does not contain valid JSON" : "შეცდომა იმპორტირებისას: ფაილი არ შეიცავს მართებულ JSON–ს",
    "Help" : "დახმარება",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Documentation" : "დოკუმენტაცია",
    "Report a bug" : "განაცხადეთ შეცდომა"
},
"nplurals=2; plural=(n!=1);");
